"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.set = void 0;
const command_factory_1 = require("./command-factory/command-factory");
const constants_1 = require("./constants");
const keyboard_1 = require("./keyboard");
exports.set = command_factory_1.commandFactory(function (keyboardShortcuts) {
    const result = [];
    keyboardShortcuts.forEach(function ({ appBundleId, menuPath, keyboardKeys: keys }) {
        result.push(`defaults write ${appBundleId} ${constants_1.DEFAULTS_KEY} -dict-add "${stringifyMenu(menuPath)}" "${stringifyKeys(keys)}"`);
    });
    const length = keyboardShortcuts.length;
    result.push(`echo "Set ${length} keyboard shortcut${length === 1 ? '' : 's'}"`);
    return result;
});
function stringifyMenu(menu) {
    return menu
        .map(function (string) {
        return `${keyboard_1.ESCAPE_KEY}${string}`;
    })
        .join('');
}
function stringifyKeys(shortcut) {
    return shortcut
        .map(function (keyboardKey) {
        if (keyboardKey === '') {
            return keyboard_1.NULL;
        }
        const character = keyboard_1.KEYBOARD_KEY_MAP[keyboardKey];
        return typeof character !== 'undefined' ? character : keyboardKey;
    })
        .join('');
}
